@@ -300,6 +300,7 @@ class FunctionRunnableKernel(FunctionRunnable):
 
         self.signals.data.emit("The code snippet:")
         self.signals.data.emit(create_code_snippet_renderable(self._func, self._args, self._kwargs))
+        self.signals.data.emit("")
 
         msg_id = self.kernel.client.execute(snippet, allow_stdin=True)
 
@@ -334,11 +335,18 @@ class FunctionRunnableKernel(FunctionRunnable):
                         elif 'text/plain' in io_msg_content['data']:
                             text = io_msg_content['data']['text/plain'].rstrip()
                             self.signals.data.emit(text)
-                # elif io_msg['msg_type'] == 'execute_input':
-                #     self.signals.data.emit("The code snippet:")
-                #     source_code = io_msg_content['code']
-                #     syntax = Syntax(source_code, "python", theme='default')
-                #     self.signals.data.emit(syntax)
+                elif io_msg_type == 'execute_input':
+                    ...  # ignore this message type
+                    #     self.signals.data.emit("The code snippet:")
+                    #     source_code = io_msg_content['code']
+                    #     syntax = Syntax(source_code, "python", theme='default')
+                    #     self.signals.data.emit(syntax)
+                elif io_msg_type == 'error':
+                    if 'traceback' in io_msg_content:
+                        traceback = io_msg_content['traceback']
+                        self.signals.data.emit(Text.from_ansi('\n'.join(traceback)))
+                else:
+                    self.signals.error.emit(RuntimeError(f"Unknown io_msg_type: {io_msg_type}"))
 
             except queue.Empty:
                 with contextlib.suppress(queue.Empty):
@@ -930,7 +938,7 @@ class FunctionButtonsPanel(QScrollArea):
 
 
 class KernelPanel(QWidget):
-    def __init__(self):
+    def __init__(self, name: str = "python3"):
         super().__init__()
 
         hbox = QHBoxLayout()
@@ -938,9 +946,9 @@ class KernelPanel(QWidget):
 
         kernel_specs = list(MyKernel.get_kernel_specs())
         try:
-            idx = kernel_specs.index("python3")
+            idx = kernel_specs.index(name)
         except ValueError:
-            idx = 0
+            idx = kernel_specs.index("python3")
         self.kernel_list = QComboBox()
         self.kernel_list.addItems(list(kernel_specs))
         self.kernel_list.setCurrentIndex(idx)
@@ -957,7 +965,7 @@ class KernelPanel(QWidget):
 
 
 class View(QMainWindow):
-    def __init__(self, app_name: str = None, cmd_log: str = None, verbosity: int = 0):
+    def __init__(self, app_name: str = None, cmd_log: str = None, verbosity: int = 0, kernel_name: str = "python3"):
         super().__init__()
 
         self._qt_console: Optional[ExternalCommand] = None
@@ -966,6 +974,7 @@ class View(QMainWindow):
         self.input_queue: Queue = Queue()
         self.previous_selected_button: Optional[DynamicButton] = None
         self.verbosity = verbosity
+        self.kernel_name = kernel_name
 
         self.cmd_log = cmd_log
         """The location of the command log files, provided as an argument."""
@@ -1036,12 +1045,12 @@ class View(QMainWindow):
 
         # Add a button to the toolbar to start the qtconsole
 
-        qtconsole_button = QAction(QIcon(str(HERE / "icons/command.svg")), "Start Qt Console", self)
+        qtconsole_button = QAction(QIcon(str(HERE / "icons/command.svg")), "Start Python Console", self)
         qtconsole_button.setStatusTip("Start the QT Console")
         qtconsole_button.triggered.connect(self.start_qt_console)
         qtconsole_button.setCheckable(False)
         self._toolbar.addAction(qtconsole_button)
-        self.kernel_panel = KernelPanel()
+        self.kernel_panel = KernelPanel(self.kernel_name)
         self._toolbar.addWidget(self.kernel_panel)
 
     def closeEvent(self, event: QCloseEvent) -> None:
@@ -1066,8 +1075,10 @@ class View(QMainWindow):
         return self._kernel
 
     def _start_new_kernel(self):
+
         if self._kernel is not None:
-            del self._kernel
+            self._kernel.shutdown()
+
         name = self.kernel_panel.selected_kernel
         # print(f"Starting new kernel {name}...")
         self._kernel = MyKernel(name)
@@ -1224,13 +1235,12 @@ class View(QMainWindow):
         self.png_widget.setLayout(layout)
         self.png_widget.show()
 
-
     @pyqtSlot(object, str, bool)
     def function_complete(self, runnable: FunctionRunnable, name: str, success: bool):
         if success:
-            self._console_panel.append(f"function '{name}' execution finished.")
+            self._console_panel.append(f"----- function '{name}' execution finished.")
         else:
-            self._console_panel.append(f"function '{name}' raised an Exception.")
+            self._console_panel.append(f"----- function '{name}' raised an Exception.")
 
         try:
             self._gui_apps.remove(runnable)
